from abc import ABC
from dataclasses import dataclass
from hf_cleaner.utils.file_utils import get_platform


@dataclass
class BaseTemplate(ABC):
    template_name: str = "Default"
    title: str = "HF Cleaner"
    platform: str = ""

    @staticmethod
    def get_os():
        os_name = get_platform()
        print(os_name)




import os
import sys
import time
import shutil
import streamlit as st
from .constants import PLATFORM, CACHE_LOC

def get_size_in_path(path="."):
        total_size = 0
        if os.path.exists(path):
            for d in os.scandir(path):
                if d.is_file() and not d.name.startswith(".") and not d.is_symlink():
                    total_size += d.stat().st_size
                elif d.is_dir():
                    total_size += get_size_in_path(d.path)
        return total_size


def get_file_info(path):
    stats = os.stat(path)
    total_size = get_size_in_path(path) / (1000 * 1000)
    return {
        'size': f"{ total_size:.2f} MB",
        'modified': time.ctime(stats.st_mtime),
        'type': 'Directory' if os.path.isdir(path) else 'File'
    }


def delete_item(path):
    try:
        if os.path.isdir(path):
            shutil.rmtree(path)
        else:
            os.remove(path)
        return True
    except Exception as e:
        st.error(f"Error deleting {path}: {str(e)}")
        return False


def get_platform():
    os_name = sys.platform
    if os_name not in PLATFORM:
        st.error(f"Not a supported platform ")
    return os_name


def hf_cache_loc():
    """
    Determine a platform-specific file location.

    Returns:
        str: The file location specific to the platform.

    Raises:
        ValueError: If the platform is not supported.
    """

    current_platform = get_platform()

    file_locations = {
        "darwin": CACHE_LOC["darwin"],
        "linux": CACHE_LOC["linux"],
        "win32": CACHE_LOC["win32"],
    }

    # Map sys.platform to user-friendly platform names if needed
    platform_map = {
        "darwin": "Darwin",
        "linux": "Linux",
        "win32": "Windows",
    }

    if current_platform not in file_locations:
        raise ValueError(f"Unsupported platform: {platform_map.get(current_platform, 'Unknown')}")
    return file_locations[current_platform]


# Example Usage
if __name__ == "__main__":
    try:
        file_loc = hf_cache_loc()
        print(f"Platform-specific file location: {file_loc}")
    except ValueError as e:
        print(f"Error: {e}")


import time
from pathlib import Path
import streamlit as st
from hf_cleaner.utils.file_utils import hf_cache_loc, get_file_info, delete_item
from .BaseTemplate import BaseTemplate


class DefaultTemplate(BaseTemplate):
    def __init__(self):
        self.file_loc: str = hf_cache_loc()
        self.create_session_states()
        self.template_name = "Default Template"
        self.layout()


    def create_session_states(self):
        if 'delete_confirm' not in st.session_state:
            st.session_state.delete_confirm = {}

        if 'delete_message' not in st.session_state:
            st.session_state.delete_message = None


    def layout(self):

        diplay_cols = (5, 2, 1, 2, 2)

        with st.sidebar:
            st.write("File Viewer Options")
            show_models = st.checkbox(label="Show Models", value=True, key="show_models_checkbox")
            show_datasets = st.checkbox(label="Show Datasets", key="show_datasets_checkbox")

        st.write(f"**HF File Directory:** {self.file_loc}")

        files = self._get_file_list(self.file_loc, show_models, show_datasets)

        columns = st.columns(diplay_cols)

        fields = ["Name", 'Type', 'Size', 'Last Modified', "Action"]

        for col, field_name in zip(columns, fields):
            col.write(field_name)

        for file in files:
            col1, col2, col3, col4, col5 = st.columns(diplay_cols)
            info = get_file_info(file)
            col1.write(file.name)
            col2.write(info["type"])
            col3.write(info["size"])
            col4.write(info["modified"])
            col5.empty()
            key = f"delete_{file.name}"
            if key not in st.session_state.delete_confirm:
                st.session_state.delete_confirm[key] = False
            if not st.session_state.delete_confirm[key]:
                if col5.button("🗑️", key=f"del_{file.name}"):
                    st.session_state.delete_confirm[key] = True
            else:
                with col5:
                    col_confirm, col_cancel = st.columns(2)
                    with col_confirm:
                        if st.button("✓", key=f"confirm_{file.name}"):
                            if delete_item(file):
                                st.session_state.delete_message = f"Deleted {file.name}"
                                time.sleep(0.1)
                                st.rerun()
                            st.session_state.delete_confirm[key] = False
                    with col_cancel:
                        if st.button("✗", key=f"cancel_{file.name}"):
                            st.session_state.delete_confirm[key] = False
                            st.rerun()

            st.html("""<hr style="height:1px;border:none;color:#333;background-color:#333;" /> """)

        if st.session_state.delete_message:
            st.success(st.session_state.delete_message)
            st.session_state.delete_message = None

    @staticmethod
    def _get_file_list(dir_path, is_list_models, is_list_datasets):
        items = list(Path(dir_path).glob('*'))
        model_list = []
        if is_list_models:
            model_list = [ path for path in items if "models--" in path.name]
        if is_list_datasets:
            datasets_list = [ path for path in items if "datasets--" in path.name]
            return model_list + datasets_list
        return model_list



import streamlit as st
from hf_cleaner.templates.DefaultTemplate import DefaultTemplate


def main():
    st.set_page_config(
        page_title="HF Cache Cleaner",
        page_icon="🧹",
        layout="wide"
    )

    DefaultTemplate()

if __name__ == "__main__":
    main()


import os

PLATFORM = ["darwin", "linux", "windows"]

CACHE_LOC = {
        "darwin": os.path.expanduser("~/.cache/huggingface/hub"),
        "linux": os.path.expanduser("~/.myapp"),
        "win32": os.path.expandvars("%APPDATA%\\MyApp"),
    }
